==> gnome-system-tools-0.25.0.tar.bz2: gnome-system-tools-0.25.0/interfaces/users.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Group Properties");
gchar *s = N_("<span weight=\"bold\">Basic Settings</span>");
gchar *s = N_("Group _name:");
gchar *s = N_("Group _ID:");
gchar *s = N_("*");
gchar *s = N_("_All users:");
gchar *s = N_("<span weight=\"bold\">Group Members</span>");
gchar *s = N_("Group _members:");
gchar *s = N_("Show a_ll users and groups");
gchar *s = N_("This is a list of the users available in the system. Create new users or edit existing user settings with this dialog.");
gchar *s = N_("_Add User...");
gchar *s = N_("_Delete");
gchar *s = N_("_Profiles...");
gchar *s = N_("Users");
gchar *s = N_("This is the list of the groups available in the system. Create new groups or edit existing groups with this dialog.");
gchar *s = N_("_Add Group...");
gchar *s = N_("_Delete");
gchar *s = N_("Groups");
gchar *s = N_("EXPERIMENTAL NIS support.\n"
              "It's only available if You have NIS\n"
              "and when You click on \"More Settings\".");
gchar *s = N_("New User");
gchar *s = N_("New Group");
gchar *s = N_("Delete");
gchar *s = N_("Change the settings and options for the\n"
              "selected user or group, like a users password\n"
              "or a groups name or members.");
gchar *s = N_("Settings");
gchar *s = N_("Settings for selected user and group");
gchar *s = N_("On this page, you can select scripts and files to be copied from your account into new users' accounts.");
gchar *s = N_("Edit profile:");
gchar *s = N_("Add");
gchar *s = N_("Delete");
gchar *s = N_("User Account Wizard");
gchar *s = N_("User Creation Druid");
gchar *s = N_("This druid is designed to help you quickly \n"
              "and easily add new users to your system.\n"
              "\n"
              "To begin, click \"Next\". ");
gchar *s = N_("User Identity (Step 1 of 2)");
gchar *s = N_("Please enter a username for the new user in the space below. Optionally, you can fill in more information to identify the user. ");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Enter Password (Step 2 of 2)");
gchar *s = N_("Please enter a password for the new user. ");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Finished");
gchar *s = N_("Congratulations, the new user has been created.\n"
              "Please click \"Finish\" to save your changes. ");
gchar *s = N_("<span weight=\"bold\">Basic Settings</span>");
gchar *s = N_("_Username:");
gchar *s = N_("_Real name:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Contact information</span>");
gchar *s = N_("O_ffice location:");
gchar *s = N_("_Work phone:");
gchar *s = N_("_Home phone:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Password</span>");
gchar *s = N_("Con_firmation:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Password set to: ");
gchar *s = N_("*");
gchar *s = N_("_Generate Password");
gchar *s = N_("Set password b_y hand");
gchar *s = N_("User _password:");
gchar *s = N_("Check password _quality");
gchar *s = N_("Generate _random password");
gchar *s = N_("Account");
gchar *s = N_("_Profile:");
gchar *s = N_("_Edit User Profiles...");
gchar *s = N_("<span weight=\"bold\">User Profile</span>");
gchar *s = N_("_Main group:");
gchar *s = N_("User _ID:");
gchar *s = N_("<span weight=\"bold\">Advanced Settings</span>");
gchar *s = N_("_Shell:");
gchar *s = N_("_Home directory:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Optional Settings</span>");
gchar *s = N_("Mi_nimum days between password changes:");
gchar *s = N_("Ma_ximum days a password may be used:");
gchar *s = N_("_Days between warning and password expiration:");
gchar *s = N_("Advanced");
gchar *s = N_("_Available groups:");
gchar *s = N_("_User's groups:");
gchar *s = N_("Other Groups");
gchar *s = N_("User Profiles - GNOME System Tools");
gchar *s = N_("User profiles can be used as templates to facilitate the creation of new users. ");
gchar *s = N_("profiles_table");
gchar *s = N_("_Add Profile...");
gchar *s = N_("On this page, you can define the system defaults which will be assigned to new users.");
gchar *s = N_("<span weight=\"bold\">Profile Settings</span>");
gchar *s = N_("Profile _name:");
gchar *s = N_("_Comments");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">System Defaults</span>");
gchar *s = N_("_Home directory:");
gchar *s = N_("Default _shell:");
gchar *s = N_("Default _group:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Password Settings</span>");
gchar *s = N_("Number of days that a password may be used:");
gchar *s = N_("Minimum days allowed between password changes:");
gchar *s = N_("Days between warning and password expiration:");
gchar *s = N_("Assign a random password by default");
gchar *s = N_("<span weight=\"bold\">Automatic UID/GID</span>");
gchar *s = N_("Maximum UID:");
gchar *s = N_("Minimum GID:");
gchar *s = N_("Minimum UID:");
gchar *s = N_("Minimum GID:");

==> gnome-system-tools-0.26.1.tar.bz2: gnome-system-tools-0.26.1/interfaces/users.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Group Properties");
gchar *s = N_("<span weight=\"bold\">Basic Settings</span>");
gchar *s = N_("Group _name:");
gchar *s = N_("Group _ID:");
gchar *s = N_("*");
gchar *s = N_("_All users:");
gchar *s = N_("<span weight=\"bold\">Group Members</span>");
gchar *s = N_("Group _members:");
gchar *s = N_("This is the list of the users available on the system. Create new users or edit existing user settings with this dialog.");
gchar *s = N_("_Add User...");
gchar *s = N_("_Delete");
gchar *s = N_("_Profiles...");
gchar *s = N_("Users");
gchar *s = N_("This is the list of the groups available on the system. Create new groups or edit existing groups with this dialog.");
gchar *s = N_("_Add Group...");
gchar *s = N_("_Delete");
gchar *s = N_("Groups");
gchar *s = N_("Show a_ll users and groups");
gchar *s = N_("EXPERIMENTAL NIS support.\n"
              "It's only available if You have NIS\n"
              "and when You click on \"More Settings\".");
gchar *s = N_("New User");
gchar *s = N_("New Group");
gchar *s = N_("Delete");
gchar *s = N_("Change the settings and options for the\n"
              "selected user or group, like a users password\n"
              "or a groups name or members.");
gchar *s = N_("Settings");
gchar *s = N_("Settings for selected user and group");
gchar *s = N_("On this page, you can select scripts and files to be copied from your account into new users' accounts.");
gchar *s = N_("Edit profile:");
gchar *s = N_("Add");
gchar *s = N_("Delete");
gchar *s = N_("User Account Wizard");
gchar *s = N_("User Creation Druid");
gchar *s = N_("This druid is designed to help you quickly \n"
              "and easily add new users to your system.\n"
              "\n"
              "To begin, click \"Next\". ");
gchar *s = N_("User Identity (Step 1 of 2)");
gchar *s = N_("Please enter a username for the new user in the space below. Optionally, you can fill in more information to identify the user. ");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Enter Password (Step 2 of 2)");
gchar *s = N_("Please enter a password for the new user. ");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Finished");
gchar *s = N_("Congratulations, the new user has been created.\n"
              "Please click \"Finish\" to save your changes. ");
gchar *s = N_("<span weight=\"bold\">Basic Settings</span>");
gchar *s = N_("_Username:");
gchar *s = N_("_Real name:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Contact Information</span>");
gchar *s = N_("O_ffice location:");
gchar *s = N_("_Work phone:");
gchar *s = N_("_Home phone:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Password</span>");
gchar *s = N_("Con_firmation:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Password set to: ");
gchar *s = N_("*");
gchar *s = N_("_Generate Password");
gchar *s = N_("Set password b_y hand");
gchar *s = N_("User _password:");
gchar *s = N_("Check password _quality");
gchar *s = N_("Generate _random password");
gchar *s = N_("Account");
gchar *s = N_("_Profile:");
gchar *s = N_("_Edit User Profiles...");
gchar *s = N_("<span weight=\"bold\">User Profile</span>");
gchar *s = N_("_Main group:");
gchar *s = N_("User _ID:");
gchar *s = N_("<span weight=\"bold\">Advanced Settings</span>");
gchar *s = N_("_Shell:");
gchar *s = N_("_Home directory:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Optional Settings</span>");
gchar *s = N_("Mi_nimum days between password changes:");
gchar *s = N_("Ma_ximum days a password may be used:");
gchar *s = N_("_Days between warning and password expiration:");
gchar *s = N_("Advanced");
gchar *s = N_("_Available groups:");
gchar *s = N_("_User's groups:");
gchar *s = N_("Other Groups");
gchar *s = N_("User Profiles - GNOME System Tools");
gchar *s = N_("User profiles can be used as templates to facilitate the creation of new users. ");
gchar *s = N_("profiles_table");
gchar *s = N_("_Add Profile...");
gchar *s = N_("On this page, you can define the system defaults which will be assigned to new users.");
gchar *s = N_("<span weight=\"bold\">Profile Settings</span>");
gchar *s = N_("Profile _name:");
gchar *s = N_("_Comments");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">System Defaults</span>");
gchar *s = N_("_Home directory:");
gchar *s = N_("Default _shell:");
gchar *s = N_("Default _group:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Password Settings</span>");
gchar *s = N_("Number of days that a password may be used:");
gchar *s = N_("Minimum days allowed between password changes:");
gchar *s = N_("Days between warning and password expiration:");
gchar *s = N_("Assign a random password by default");
gchar *s = N_("<span weight=\"bold\">Automatic UID/GID</span>");
gchar *s = N_("Maximum UID:");
gchar *s = N_("Minimum GID:");
gchar *s = N_("Minimum UID:");
gchar *s = N_("Minimum GID:");
